@@ -1,5 +1,5 @@
 package Crypt::HSM::Session;
-$Crypt::HSM::Session::VERSION = '0.016';
+$Crypt::HSM::Session::VERSION = '0.017';
 use strict;
 use warnings;
 
@@ -22,22 +22,19 @@ Crypt::HSM::Session - A PKCS11 session
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 SYNOPSIS
 
+ $session->login('user', $password) if defined $password;
+
+ my ($key) = $session->find_objects({ label => $label, encrypt => 1 });
+ if (not $key) {
+	$key = $session->generate_key('aes-key-gen', { label => $label, sensitive => 1, "value-len" => 32 });
+ }
+ my $iv = $session->generate_random(16);
  $session->encrypt('aes-cbc', $key, $plaintext, $iv);
 
- $session->sign('sha256-hmac', $key, $data);
-
- $session->verify('sha256-rsa-pkcs', $key, $data, $signature);
-
- my $key = $session->generate_key($type, { token => 1, sensitive => 1 });
-
- my @keys = $session->find_objects({ class => 'secret-key' });
-
- my $attrs = $session->get_attributes($key, [ 'private', 'sensitive' ]);
-
 =head1 DESCRIPTION
 
 This represents a session with a PKCS module such as an HSM. It does most of the cryptographic work of using a PKCS11 interface.
@@ -60,49 +57,43 @@ This is an identifier that refers to resource inside the HSM, it has no meaning
 
 This is a mechanism for a cryptographic operation, e.g. C<'aes-gcm'>, C<'sha256-rsa-pkcs'> or C<'sha512-hmac'>. The list of supported mechanisms can be retrieved using the C<mechanisms> method on the C<Crypt::HSM> object.
 
-Cryptographic methods taking taking an argument will also take zero or more mechanism specific arguments after their generic arguments, for example an IV or nonce for a symmetric cipher that uses such, or a public key for a Diffie-Hellman derivation.
-
 =item attributes
 
 This is an hash of attributes. The key is the name of the attribute (e.g. C<'class'>, C<'sensitive'>), the value depends on the key but is usually either an integer, a string or a bool.
 
 =back
 
+=head2 Additional arguments
+
+Many functions will also take one or more mechanism specific additional arguments after their generic arguments, for example an IV or nonce for a symmetric cipher, or a public key for a Diffie-Hellman derivation. Where supported these are documented in L<Crypt::HSM::Mechanism|Crypt::HSM::Mechanism>.
+
 =head1 METHODS
 
-=head2 copy_object($object, $attributes)
-
-Copy an object, optionally adding/modifying the given attributes.
-
 =head2 create_object($attributes)
 
-Create an object with the given C<$attribute> hash.
+Create an object with the given C<$attribute> hash. This returns a L<Crypt::HSM::Key|Crypt::HSM::Key> object.
 
 =head2 decrypt($mechanism, $key, $ciphertext, ...)
 
-Decrypt C<$ciphertext> with C<$mechanism> and C<$key>.
+Decrypt C<$ciphertext> with C<$mechanism> and C<$key>. This may take mechanism dependent additional arguments such as an IV.
 
 =head2 derive_key($mechanism, $key, $attributes, ...)
 
-Derive a new key from C<$key>, using mechanism and setting C<$attributes> on it.
-
-=head2 destroy_object($object)
-
-This deletes the object with the identifier C<$object>.
+Derive a new key from C<$key>, using mechanism and setting C<$attributes> on it. This may take mechanism dependent additional arguments. This returns a L<Crypt::HSM::Key|Crypt::HSM::Key> object.
 
 =head2 digest($mechanism, $key, $input, ...)
 
-Digest C<$input> with C<$mechanism> and C<$key>.
+Digest C<$input> with C<$mechanism> and C<$key>. This may take mechanism dependent additional arguments.
 
 =head2 encrypt($mechanism, $key, $plaintext, ...)
 
-Encrypt C<$plaintext> with C<$mechanism> and C<$key>.
+Encrypt C<$plaintext> with C<$mechanism> and C<$key>. This may take mechanism dependent additional arguments such as an IV.
 
 =head2 find_objects($attributes)
 
-Find all objects that satisfy the given C<$attributes>.
+Find all objects that satisfy the given C<$attributes>. This returns a list of L<Crypt::HSM::Key|Crypt::HSM::Key> objects.
 
-=head2 generate_key($mechanism, $attributes, ...)
+=head2 generate_key($mechanism, \%attributes)
 
 Generate a new key for C<$mechanism> with C<$attributes>. Some relevant attributes are:
 
@@ -142,24 +133,16 @@ This sets the length of a key, this can be useful when creating a C<'generic-sec
 
 =back
 
-Most of these have implementation-specific defaults.
+Most of these have implementation-specific defaults. This returns a L<Crypt::HSM::Key|Crypt::HSM::Key> object.
 
-=head2 generate_keypair($mechanism, $public_attributes, $private_attributes, ...)
+=head2 generate_keypair($mechanism, \%public_attributes, \%private_attributes)
 
-This generates a key pair. The attributes for the public and private keys work similar to `generate_key`.
+This generates a key pair. The attributes for the public and private keys work similar to `generate_key`. This returns two L<Crypt::HSM::Key|Crypt::HSM::Key> objects.
 
 =head2 generate_random($length)
 
 This generate C<$length> bytes of randomness.
 
-=head2 get_attribute($object, $attribute_name)
-
-This returns the value of the named attribute.
-
-=head2 get_attributes($object, $attribute_list)
-
-This returns a hash with the attributes that are asked for.
-
 =head2 info()
 
 This returns information about the current session.
@@ -170,35 +153,31 @@ This initializes the PIN for this slot.
 
 =head2 login($type, $pin)
 
-Log in the current session. C<$type> should be either C<'user'> (most likely), C<'so'> (security officer, for elevated privileges), or C<'context-dependent'>. C<$pin> is your password.
+Log in the current session. C<$type> should be either C<'user'> (most likely), C<'so'> (security officer, for elevated privileges), or C<'context-dependent'>. C<$pin> is your password. This is needed on some providers but not all.
 
 =head2 logout()
 
 Log the current session out.
 
-=head2 object_size($object)
-
-This returns the size of C<$object>.
-
 =head2 open_decrypt($mechanism, $key, ...)
 
-Start a decryption with C<$mechanism> and C<$key>. This returns a L<Crypt::HSM::Decrypt|Crypt::HSM::Decrypt> object.
+Start a decryption with C<$mechanism> and C<$key>. This returns a L<Crypt::HSM::Decrypt|Crypt::HSM::Decrypt> object. This may take mechanism dependent additional arguments such as an IV.
 
 =head2 open_digest($mechanism, ...)
 
-Start a digest with C<$mechanism>. This returns a L<Crypt::HSM::Digest|Crypt::HSM::Digest> object.
+Start a digest with C<$mechanism>. This returns a L<Crypt::HSM::Digest|Crypt::HSM::Digest> object. This may take mechanism dependent additional arguments.
 
 =head2 open_encrypt($mechanism, $key, ...)
 
-Start an encryption with C<$mechanism> and C<$key>. This returns a L<Crypt::HSM::Encrypt|Crypt::HSM::Encrypt> object.
+Start an encryption with C<$mechanism> and C<$key>. This returns a L<Crypt::HSM::Encrypt|Crypt::HSM::Encrypt> object. This may take mechanism dependent additional arguments such as an IV.
 
 =head2 open_sign($mechanism, $key, ...)
 
-Start an signing with C<$mechanism> and C<$key>. This returns a L<Crypt::HSM::Sign|Crypt::HSM::Sign> object.
+Start an signing with C<$mechanism> and C<$key>. This returns a L<Crypt::HSM::Sign|Crypt::HSM::Sign> object. This may take mechanism dependent additional arguments.
 
 =head2 open_verify($mechanism, $key, ...)
 
-Start an verification with C<$mechanism> and C<$key>. This returns a L<Crypt::HSM::Verify|Crypt::HSM::Verify> object.
+Start an verification with C<$mechanism> and C<$key>. This returns a L<Crypt::HSM::Verify|Crypt::HSM::Verify> object. This may take mechanism dependent additional arguments.
 
 =head2 provider()
 
@@ -208,17 +187,13 @@ Returns the provider object for this session.
 
 Mix additional seed material into the token’s random number generator.
 
-=head2 set_attributes($object, $attributes)
-
-This sets the C<$attributes> on C<$object>.
-
 =head2 set_pin($old_pin, $new_pin)
 
 This changes the PIN from C<$old_pin> to C<$new_pin>.
 
 =head2 sign($mechanism, $key, $input, ...)
 
-This creates a signature over C<$input> using C<$mechanism> and C<$key>.
+This creates a signature over C<$input> using C<$mechanism> and C<$key>. This may take mechanism dependent additional arguments.
 
 =head2 slot()
 
@@ -226,11 +201,11 @@ Returns the slot identifier used for this session.
 
 =head2 unwrap_key($mechanism, $unwrap_key, $wrapped_key, $attributes, ...)
 
-This unwraps the key wrapped in the bytearray C<$wrapped_key> using C<mechanism> and key C<$unwrap_key>, setting C<$attributes> on the new key.
+This unwraps the key wrapped in the bytearray C<$wrapped_key> using C<mechanism> and key C<$unwrap_key>, setting C<$attributes> on the new key. This returns a L<Crypt::HSM::Key|Crypt::HSM::Key> object.
 
 =head2 verify($mechanism, $key, $data, $signature, ...)
 
-Verify that C<$signature> matches C<$data>, using C<$mechanism> and C<$key>.
+Verify that C<$signature> matches C<$data>, using C<$mechanism> and C<$key>. This may take mechanism dependent additional arguments
 
 =head2 wrap_key($mechanism, $wrap_key, $key, ...)
 
@@ -238,7 +213,7 @@ This wraps key C<$key> using C<$mechanism> and key C<$wrap_key>.
 
 =head1 AUTHOR
 
-Leon Timmermans <leont@cpan.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
